Gentelella Alela! |

Welcome,

## John Doe

### Tables Some examples to get you started

## Basic Tables basic table subtitle

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Mark | Otto | @mdo
2 | Jacob | Thornton | @fat
3 | Larry | the Bird | @twitter

## Stripped table Stripped table subtitle

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Mark | Otto | @mdo
2 | Jacob | Thornton | @fat
3 | Larry | the Bird | @twitter

## Hover rows Try hovering over the rows

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Mark | Otto | @mdo
2 | Jacob | Thornton | @fat
3 | Larry | the Bird | @twitter

## Boardered table Bordered table subtitle

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Mark | Otto | @mdo
2 | Jacob | Thornton | @fat
3 | Larry | the Bird | @twitter

## Table design Custom design

Add class `bulk_action` to table for bulk actions options on row select

| Invoice | Invoice Date | Order | Bill to Name | Status | Amount | Action | Bulk Actions ( )
--- | --- | --- | --- | --- | --- | --- | --- | ---
| 121000040 | May 23, 2014 11:47:56 PM | 121000210 | John Blank L | Paid | $7.45 | View
| 121000039 | May 23, 2014 11:30:12 PM | 121000208 | John Blank L | Paid | $741.20 | View
| 121000038 | May 24, 2014 10:55:33 PM | 121000203 | Mike Smith | Paid | $432.26 | View
| 121000037 | May 24, 2014 10:52:44 PM | 121000204 | Mike Smith | Paid | $333.21 | View
| 121000040 | May 24, 2014 11:47:56 PM | 121000210 | John Blank L | Paid | $7.45 | View
| 121000039 | May 26, 2014 11:30:12 PM | 121000208 | John Blank L | Paid | $741.20 | View
| 121000038 | May 26, 2014 10:55:33 PM | 121000203 | Mike Smith | Paid | $432.26 | View
| 121000037 | May 26, 2014 10:52:44 PM | 121000204 | Mike Smith | Paid | $333.21 | View
| 121000040 | May 27, 2014 11:47:56 PM | 121000210 | John Blank L | Paid | $7.45 | View
| 121000039 | May 28, 2014 11:30:12 PM | 121000208 | John Blank L | Paid | $741.20 | View